@@ -44,16 +44,13 @@ class EndPoint(object):
                     configuration=self.api_client.configuration
                 )
 
-        if kwargs['_check_input_type'] is False:
-            return
-
         for key, value in kwargs.items():
             fixed_val = validate_and_convert_types(
                 value,
                 openapi_types[key],
                 [key],
                 False,
-                kwargs['_check_input_type'],
+                True,
                 configuration=self.api_client.configuration
             )
             kwargs[key] = fixed_val
@@ -110,5 +107,5 @@ class EndPoint(object):
 
         for chunk in iter(partial(file.read, self.api_client.configuration.chunk_size), b''):
             offset = index + len(chunk)
-            yield 'bytes {}-{}/{}'.format(index, offset - 1, file_size), {file_name: [ChunkIO(chunk, file.name)]}
+            yield 'bytes {}-{}/{}'.format(index, offset - 1, file_size), {file_name: [ChunkIO(chunk, file.name)]}, offset == file_size
             index = offset
